
<style>
    * {
        margin: 0;
        padding: 0;
        box-sizing: border-box;
    }
</style>

<body>
    hihi

    <div>
        <h1>Helleo22323</h1>
    </div>
<div style="border: 5px solid green; width: 100%">AA
    <div style="border: 10px solid red; padding: 10px; margin: 10px; width: 100%">B</div>
</div>
</body>